pub struct ImageModelCallOptions {
pub prompt: Option<String>,
pub n: u32,
pub size: Option<ImageModelCallOptionsSize>,
pub aspect_ratio: Option<ImageModelCallOptionsAspectRatio>,
pub seed: Option<u64>,
pub files: Option<Vec<ImageModelFile>>,
pub mask: Option<ImageModelFile>,
pub provider_options: Option<ProviderOptions>,
pub abort_signal: Option<CancellationToken>,
pub headers: Option<HeaderMap>,
}Expand description
The options for calling an image generation model.
Fields
prompt: Option<String>An optional prompt to guide the image generation, if supported by the model.
n: u32The number of images to generate.
size: Option<ImageModelCallOptionsSize>The desired size of the generated images.
aspect_ratio: Option<ImageModelCallOptionsAspectRatio>The desired aspect ratio of the generated images, if supported by the model.
seed: Option<u64>An optional seed for the random number generator, if supported by the model.
files: Option<Vec<ImageModelFile>>Optional files to use as input for the image generation, if supported by the model.
mask: Option<ImageModelFile>An optional file to use as a mask for inpainting, if supported by the model.
provider_options: Option<ProviderOptions>Optional provider-specific options for the image generation model.
abort_signal: Option<CancellationToken>An optional signal to abort the image generation request.
headers: Option<HeaderMap>Optional HTTP headers to include in the image generation request.