pub struct LanguageModelRawRequest {
pub headers: Option<HeaderMap>,
pub body: Value,
}Expand description
Represents the raw request sent to a Language Model provider.
Fields
headers: Option<HeaderMap>The request headers as a map of header name to value
body: ValueThe request body as JSON value