LanguageModelAssistantContent

Enum LanguageModelAssistantContent 

pub enum LanguageModelAssistantContent {
    Text {
        text: String,
        provider_options: Option<ProviderOptions>,
    },
    Reasoning {
        text: String,
        provider_options: Option<ProviderOptions>,
    },
    File {
        filename: Option<String>,
        data: LanguageModelDataContent,
        media_type: String,
        provider_options: Option<ProviderOptions>,
    },
    ToolCall {
        tool_call_id: String,
        tool_name: String,
        input: JsonValue,
        provider_executed: Option<bool>,
        provider_options: Option<ProviderOptions>,
    },
    ToolResult {
        tool_call_id: String,
        tool_name: String,
        output: JsonValue,
        provider_options: Option<ProviderOptions>,
    },
}

Variants



Text

type: “text”

Fields

text: String

The text content

provider_options: Option<ProviderOptions>

Provider-specific metadata



Reasoning

type: “reasoning”

Fields

text: String

The reasoning content as text

provider_options: Option<ProviderOptions>

Provider-specific metadata



File

type: “file”

Fields

filename: Option<String>

The file name, if available

data: LanguageModelDataContent

The file data, which can be bytes, a string, or a URL

media_type: String

The IANA media type

provider_options: Option<ProviderOptions>

Provider-specific metadata



ToolCall

type: “tool-call”

Fields

tool_call_id: String

The tool call ID

tool_name: String

The tool name

input: JsonValue

The tool input, which can be any JSON value

provider_executed: Option<bool>

Whether the tool call was executed by the provider

provider_options: Option<ProviderOptions>

Provider-specific metadata



ToolResult

type: “tool-result”

Fields

tool_call_id: String

The tool call ID that this result corresponds to

tool_name: String
output: JsonValue
provider_options: Option<ProviderOptions>

Provider-specific metadata