pub struct LanguageModelStreamResult {
pub stream: Pin<Box<dyn Stream<Item = LanguageModelStreamPart> + Send>>,
pub request: Option<LanguageModelStreamResultRequest>,
pub response: Option<LanguageModelStreamResultResponse>,
}Expand description
Represents the result of a streaming language model call.
Fields
stream: Pin<Box<dyn Stream<Item = LanguageModelStreamPart> + Send>>The stream of partial results from the language model provider.
request: Option<LanguageModelStreamResultRequest>The request sent to the language model provider.
response: Option<LanguageModelStreamResultResponse>The response received from the language model provider.