ImageModelRouter

Trait ImageModelRouter 

pub trait ImageModelRouter {
    // Required method
    fn route_model(
        &self,
        target: RoutingTarget,
    ) -> impl Future<Output = Result<Box<DynImageModel<'static>>>> + Send;
}
A router that routes to the appropriate image model implementation based on the routing target.

Required Methods

fn route_model( &self, target: RoutingTarget, ) -> impl Future<Output = Result<Box<DynImageModel<'static>>>> + Send

Routes to the appropriate image model implementation based on the routing target.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors